# This library is for test and portfolio
## Notes
Since it is a combination of learning and portfolio, please install at your own risk.
## How to use
will be available in "import filename"
## Available modules
Example "filename.functionname" can be used
##### mcd(Methods that return the greatest common divisor)argument(int a, int b)
x = filename.mcd(a,b)
Returns the greatest common divisor of type int

## Other matters
We will add things that have been learned as functions at any time.
If you have any problems or anomalies, please let me know.
